==> JDFLibJ-2.1.8.10-sources.jar: org/cip4/jdflib/datatypes/StringCache.java <==
/*
 *
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2020 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments
 * normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior written permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 *
 */
/**
 *
 * Copyright (c) 2001 Heidelberger Druckmaschinen AG, All Rights Reserved.
 *
 * JDFAttribute.java
 *
 * Last changes
 *
 */
package org.cip4.jdflib.datatypes;

import java.util.Collection;
import java.util.HashMap;

import org.cip4.jdflib.auto.JDFAutoPart.EnumSide;
import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.JDFConstants;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.resource.process.JDFColor;

/**
 *
 */
public class StringCache
{
	static private HashMap<String, String> theSet = null;

	private StringCache()
	{
	}

	/**
	 *
	 */
	static public void enable(final boolean enable)
	{

		if (enable && theSet == null)
		{
			theSet = new HashMap<>();
			getCreateString(JDFConstants.EMPTYSTRING);
			getCreateString(JDFConstants.SLASH);
			getCreateString(JDFConstants.SPACE);
			getCreateString(JDFConstants.TRUE);
			getCreateString(JDFConstants.FALSE);
			getCreateString(ElementName.JDF);
			getCreateString(ElementName.JMF);
			getCreateString(XJDFConstants.XJDF);
			getCreateString(XJDFConstants.XJMF);
			getCreateString(new JDFIntegerRange(0, -1).getString(0));
			getCreateString("-1");
			for (int i = 0; i < 32; i++)
			{
				getCreateString("" + i);
			}
			for (final String c : JDFColor.getCMYKSeparations())
				getCreateString(c);
			getCreateString(EnumSide.Front.getName());
			getCreateString(EnumSide.Back.getName());
		}
		else if (!enable)
		{
			theSet = null;
		}
	}

	/**
	 *
	 * @param s
	 * @return
	 */
	public static String getCreateString(final String s)
	{
		if (theSet != null)
		{
			final String s2 = theSet.get(s);
			if (s2 != null)
			{
				return s2;
			}
			else
			{
				theSet.put(s, s);
			}
		}
		return s;
	}

	/**
	 * gets strings if they are there, eles only fills short strings up to length 2
	 *
	 * @param s
	 * @return
	 */
	public static String getString(final String s)
	{
		if (theSet != null)
		{
			final String s2 = theSet.get(s);
			if (s2 != null)
			{
				return s2;
			}
			else if (s != null && s.length() < 3)
			{
				theSet.put(s, s);
			}
		}
		return s;
	}

	/**
	 *
	 * @return the number of cached strings
	 */
	public static int size()
	{
		return theSet == null ? 0 : theSet.size();
	}

	/**
	 *
	 * @param c
	 */
	public static void addAll(final Collection<String> c)
	{
		if (c != null && theSet != null)
		{
			for (final String s : c)
			{
				getCreateString(s);
			}
		}
	}
}

==> JDFLibJ-2.1.8.12-sources.jar: org/cip4/jdflib/datatypes/StringCache.java <==
/*
 *
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2025 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments
 * normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior written permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 *
 */
/**
 *
 * Copyright (c) 2001 Heidelberger Druckmaschinen AG, All Rights Reserved.
 *
 * JDFAttribute.java
 *
 * Last changes
 *
 */
package org.cip4.jdflib.datatypes;

import java.util.Collection;

/**
 * @deprecated - simply use the jave intern method
 */
@Deprecated
public class StringCache
{

	private StringCache()
	{
	}

	/**
	 *
	 */
	static public void enable(final boolean enable)
	{

	}

	/**
	 *
	 * @param s
	 * @return
	 */
	public static String getCreateString(final String s)
	{
		return s == null ? null : s.intern();
	}

	/**
	 * gets strings if they are there, eles only fills short strings up to length 2
	 *
	 * @param s
	 * @return
	 */
	public static String getString(final String s)
	{

		return s == null ? null : s.intern();
	}

	/**
	 *
	 * @return the number of cached strings
	 */
	public static int size()
	{
		return 0;
	}

	/**
	 *
	 * @param c
	 */
	public static void addAll(final Collection<String> c)
	{
	}
}
